@@ -14,7 +14,7 @@ $page->assign('available',__("The following barrels are currently available"));
 $page->assign('msg_site',__("site"));
 $page->assign('msg_desc',__("description"));
 
-$res = $globals->db->query("select alias,vhost from diogenes_site");
+$res = $globals->db->query("select alias,vhost from diogenes_site order by alias");
 $odd = false;
 while (list($s_alias,$s_vhost) = mysql_fetch_row($res)) {
   $opts = new DiogenesBarrelOptions($s_alias);
