@@ -8,14 +8,14 @@ if (preg_match("/^\/([^\/]+)\/webdav(\/.*)?$/",$_SERVER['PATH_INFO'],$tmp)) {
   $server->ServeRequest();
 
 } elseif (preg_match("/^\/([^\/]+)\/admin\/(.*)/",$_SERVER['PATH_INFO'],$tmp)) {
-
-  if ($tmp[2] == "ekitapplet.jar") {
+  $afile = $tmp[2];
+  if (preg_match("/^(ekitapplet|gnu-regexp-1.1.4|kafenio-config|kafenio-icons|kafenio)\.jar$/", $afile)) {
     header("Content-Type: application/java-archive");
-    header("Last-modified:".gmdate("D, d M Y H:i:s T", filemtime("ekitapplet.jar")));
-    readfile("ekitapplet.jar");
+    header("Last-modified:".gmdate("D, d M Y H:i:s T", filemtime($afile)));
+    readfile($afile);
   } else {
     // include the requested admin page
-    require("admin/". ($tmp[2] ? "{$tmp[2]}.php" : "index.php"));
+    require("admin/". ($afile ? "$afile.php" : "index.php"));
   }
 
 } else {
