@@ -1,7 +1,7 @@
 <?php
 require_once 'diogenes.common.inc.php';
 require_once 'diogenes.toplevel.inc.php';
-require_once 'diogenes.logger-view.inc.php';
+require_once 'diogenes/diogenes.logger-view.inc.php';
 
 $page = new $globals->toplevel(true);
 $page->assign('greeting', __("User activity log"));
