@@ -1,7 +1,7 @@
 <?php
 require_once 'diogenes.common.inc.php';
 require_once 'diogenes.toplevel.inc.php';
-require_once 'diogenes.logger-view.inc.php';
+require_once 'diogenes/diogenes.logger-view.inc.php';
 // dependency on PEAR
 require_once 'System.php';
 
@@ -57,6 +57,8 @@ case "options":
     $globals->updateOption("menu_theme", $_REQUEST['menu_theme']);
   $globals->updateOption("template_dir", $_REQUEST['template_dir']);
   $globals->updateOption("template", $_REQUEST['template']);
+  $globals->updateOption("html_editor", $_REQUEST['html_editor']);
+  $globals->updateOption("word_import", $_REQUEST['word_import']);
   break;
 }
 
@@ -72,16 +74,23 @@ $page->assign('template_dir', $globals->template_dir);
 $page->assign('template', $globals->template);
 $page->assign('templates', $page->getTemplates());
 
+$page->assign('html_editors', $globals->html_editors);
+$page->assign('html_editor', $globals->html_editor);
+
+$page->assign('word_imports', $globals->word_imports);
+$page->assign('word_import', $globals->word_import);
 
 // translations
 $page->assign('greeting', __("Global options"));
 $page->toolbar(__("Mode"), array( __("standard"), array(__("expert"), "options_expert.php")));
-$page->assign('msg_menu_options', __("menu options"));
+$page->assign('msg_display_options', __("display options"));
 $page->assign('msg_menu_style', __("menu style"));
 $page->assign('msg_menu_theme', __("menu theme"));
-$page->assign('msg_template_options', __("template options"));
 $page->assign('msg_site_template_dir', __("templates directory"));
 $page->assign('msg_site_template', __("default template"));
+$page->assign('msg_system_options', __("system options"));
+$page->assign('msg_html_editor', __("HTML editor"));
+$page->assign('msg_word_import', __("Word document import"));
 $page->assign('msg_submit', __("Submit"));
 $page->assign('msg_convert',__("Convert"));
 $page->assign('msg_vcs',__("version control system"));
