@@ -1,7 +1,7 @@
 <?php
 require_once 'diogenes.common.inc.php';
 require_once 'diogenes.toplevel.inc.php';
-require_once 'diogenes.table-editor.inc.php';
+require_once 'diogenes/diogenes.table-editor.inc.php';
 
 // set up the page
 $page = new $globals->toplevel(true);
@@ -12,8 +12,6 @@ $page->toolbar(__("Mode"), array( array( __("standard"), "options.php" ), __("ex
 $editor = new DiogenesTableEditor($globals->table_global_options,"name",true);
 $editor->describe("name", __("option"), false);
 $editor->describe("value", __("value"), true);
-$page->assign('msg_standard_mode', __("standard mode"));
-$page->assign('msg_expert_mode', array( __("expert mode"), 'options_edit.php'));
 
 // run the editor
 $editor->run($page,'page_content');
