@@ -33,7 +33,7 @@ $topbar = array (
 $filebar = array();
 if ($canedit) {
   array_push($filebar, array( __("raw editor"), "edit?dir=$dir&amp;file=$target"));
-  array_push($filebar, array( __("HTML editor"), "ekit?dir=$dir&amp;file=$target"));
+  array_push($filebar, array( __("HTML editor"), "compose?dir=$dir&amp;file=$target"));
 }
 
 // translations
