@@ -25,8 +25,6 @@ require_once 'diogenes.barrel.options.inc.php';
 /** This class is used to display a page of a Diogenes barrel,
  *  that is an RCS-managed website with a virtual directory
  *  structure.
- *
- * @version $Id: diogenes.barrel.inc.php,v 1.142 2004/06/07 12:28:03 x99laine Exp $
  */
 class DiogenesBarrel extends DiogenesPage
 {
@@ -58,8 +56,10 @@ class DiogenesBarrel extends DiogenesPage
   var $canedit = false;
 
   /** The constructor.
+   *
+   * @PARAM override_pathinfo 
    */
-  function DiogenesBarrel()
+  function DiogenesBarrel($override_pathinfo = null)
   {
     global $globals;
 
@@ -67,7 +67,8 @@ class DiogenesBarrel extends DiogenesPage
     $this->DiogenesPage();
 
     // break down PATH_INFO into site and location components
-    $this->pathinfo = $this->parsePathInfo($_SERVER['PATH_INFO']);
+    $mypathinfo = $override_pathinfo ? $override_pathinfo : $_SERVER['PATH_INFO'];
+    $this->pathinfo = $this->parsePathInfo($mypathinfo);
     if (!$this->pathinfo)
       $this->kill404("Invalid location specified!");
     $this->alias = $this->pathinfo['alias'];
@@ -270,11 +271,16 @@ class DiogenesBarrel extends DiogenesPage
     array_push($this->head, '<meta name="keywords" content="'.stripslashes($this->options->keywords).'" />');
 
     // stylesheets
-    array_push($this->head, '<link rel="stylesheet" href="'.$this->url("common.css").'" type="text/css" />');
+    $this->sheets = array();
+    array_push($this->sheets, $this->url("common.css"));
     if ($this->options->menu_style == 1 || $this->options->menu_style == 2) 
-      array_push($this->head, '<link rel="stylesheet" href="'.$this->url("phplayersmenu/{$this->options->menu_theme}/style.css").'" type="text/css" />');
-    array_push($this->head, '<link rel="stylesheet" href="'.$this->urlSite($globals->cssfile).'" type="text/css" />');
-
+      array_push($this->sheets, $this->url("phplayersmenu/{$this->options->menu_theme}/style.css"));
+    array_push($this->sheets, $this->urlSite($globals->cssfile));
+    
+    // add stylesheets to head
+    foreach ($this->sheets as $mysheet) {
+      array_push($this->head, '<link rel="stylesheet" href="'.$mysheet.'" type="text/css" />');
+    }
     // favicon
     if ($this->options->favicon)
       array_push($this->head, '<link rel="icon" href="'.$this->urlSite($this->options->favicon).'" type="image/png" />');
@@ -291,23 +297,26 @@ class DiogenesBarrel extends DiogenesPage
     $this->assign('menutheme', $this->options->menu_theme);
     
     // build the Diogenes part of the menu
-    array_push($this->menu,array(1,__("Home"),$this->urlSite("")));
-    if ($this->isLogged()) {
-      array_push($this->menu, array(1,__("Logout"), "?dologout=1") );
-    } else {
-      array_push($this->menu, array(1,__("Login"), "?doauth=1") );
-    }
+    if (!$this->options->menu_hide_diogenes) {
+      array_push($this->menu,array(0,__("Home"),$this->urlSite(""), 1));
+      if ($this->isLogged()) {
+        array_push($this->menu, array(1,__("Logout"), "?dologout=1") );
+        array_push($this->menu, array(1,__("Preferences"), $this->urlSite("admin/prefs")));
+      } else {
+        array_push($this->menu, array(1,__("Login"), "?doauth=1") );
+      }
     
-    if ($this->isAdmin()) {
-      array_push($this->menu, array(0, __("Administration"), $this->urlSite("admin/"), 1));
-      if ($this->PID)
-        array_push($this->menu, array(1, __("Page properties"), $this->urlSite("admin/pages?PID={$this->PID}")));
-    } elseif ($this->canedit && $this->PID) {
-      array_push($this->menu, array(0, __("Edit this page"), "", 1));
-      array_push($this->menu, array(1, __("Raw editor"), $this->urlSite("admin/edit?dir={$this->PID}&amp;file={$globals->htmlfile}")));
-      array_push($this->menu, array(1, __("HTML editor"), $this->urlSite("admin/ekit?dir={$this->PID}&amp;file={$globals->htmlfile}")));
+      if ($this->isAdmin()) {
+        array_push($this->menu, array(1, __("Administration"), $this->urlSite("admin/")));
+        if ($this->PID)
+          array_push($this->menu, array(1, __("Page properties"), $this->urlSite("admin/pages?PID={$this->PID}")));
+      } elseif ($this->canedit && $this->PID) {
+        array_push($this->menu, array(0, __("Edit this page"), "", 1));
+        array_push($this->menu, array(1, __("Raw editor"), $this->urlSite("admin/edit?dir={$this->PID}&amp;file={$globals->htmlfile}")));
+        array_push($this->menu, array(1, __("HTML editor"), $this->urlSite("admin/compose?dir={$this->PID}&amp;file={$globals->htmlfile}")));
+      }
     }
-   
+
     // if this is an error page, we need to bail out here
     if (!isset($this->table_menu))
       return;
@@ -365,7 +374,6 @@ class DiogenesBarrel extends DiogenesPage
 
     while(list($mid,$title,$link,$pid,$location) = mysql_fetch_row($res)) {
       $title = stripslashes($title);
-      $aclass =  ($MIDpere && !($level%2))  ? "class='odd' " : "";
       $entry = htmlentities(stripslashes($title), ENT_QUOTES);
       $link = $pid ? $this->urlSite($location ? "$location/" : "") : $link;      
       // decide whether this menu should be expanded
