@@ -19,11 +19,9 @@
  */
 
 
-require_once 'diogenes.core.globals.inc.php';
+require_once 'diogenes/diogenes.core.globals.inc.php';
 
 /** This class describes Diogenes' global settings.
- *
- * @version $Id: diogenes.globals.inc.php.in,v 1.22 2004/06/07 12:27:29 x99laine Exp $
  */
 class DiogenesGlobals extends DiogenesCoreGlobals {
   /** Absolute directory location of Diogenes root. */
@@ -35,7 +33,7 @@ class DiogenesGlobals extends DiogenesCoreGlobals {
   /** The Diogenes root URL */
   var $rooturl;
   /** The Diogenes version */
-  var $version = "0.9.14";
+  var $version = "0.9.16";
 
   /** A barrel's stylesheet */
   var $cssfile = "style.css";
@@ -56,7 +54,7 @@ class DiogenesGlobals extends DiogenesCoreGlobals {
   var $session = 'DiogenesSession';
   /** The class to use for WebDAV operations. */
   var $webdav = 'DiogenesWebDAV';
-
+ 
   /** The database table holding the global options */
   var $table_global_options = "diogenes_option";
 
@@ -76,7 +74,13 @@ class DiogenesGlobals extends DiogenesCoreGlobals {
 
   /** Invalid barrel names */
   var $invalidaliases = array("CVSROOT", "templates_c", "diogenes");
-  
+ 
+  /** Available HTML editors */
+  var $html_editors = array(
+                             'kafenio' => "Kafenio",
+			     'ekit' => "Ekit"
+                           );
+
   /** Availables languages */
   var $locales = array(
                        'en_US'=> "English",
@@ -101,6 +105,9 @@ class DiogenesGlobals extends DiogenesCoreGlobals {
                            'mozilla' => 'mozilla'
                           );
   
+  /** The HTML editor to use (ekit, kafenio) */
+  var $html_editor = "kafenio";
+ 
   /** Toplevel menu style */
   var $menu_style = 0;
 
@@ -113,6 +120,15 @@ class DiogenesGlobals extends DiogenesCoreGlobals {
   /** Default template for barrel pages */
   var $template = "";
   
+  /** Utility to use for Word file import */
+  var $word_import = "wvHtml";
+  
+  /** Available Word import utilities */  
+  var $word_imports = array(
+                             ''       => "disabled", 
+                             'wvHtml' => "wvHtml"
+                           );  
+  
   /** Read extra options from database.
    */
   function readOptions() {
