@@ -19,15 +19,13 @@
  */
 
 
-require_once 'diogenes.core.page.inc.php';
-require_once 'diogenes.misc.inc.php';
+require_once 'diogenes/diogenes.core.page.inc.php';
+require_once 'diogenes/diogenes.misc.inc.php';
 
 /** This class describes a generic Diogenes page. This class
  *  is inherited to display barrel, admin or toplevel pages.
  *
  * @see DiogenesBarrel DiogenesAdmin DiogenesToplevel
- *
- * @version $Id: diogenes.page.inc.php,v 1.122 2004/06/01 12:46:29 x99laine Exp $
  */
 class DiogenesPage extends DiogenesCorePage
  {
