@@ -20,7 +20,7 @@
 
 
 require_once 'HTTP/WebDAV/Server.php';
-require_once 'diogenes.misc.inc.php';
+require_once 'diogenes/diogenes.misc.inc.php';
 require_once 'diogenes.webdav.logger.inc.php';
 
 /**
@@ -390,7 +390,7 @@ class DiogenesWebDAV extends HTTP_WebDAV_Server
       return "400 Error";
     
     // if this is Word master document, do the HTML conversion
-    if ($pathinfo['file'] == $globals->wordfile) {
+    if ($globals->word_import && $pathinfo['file'] == $globals->wordfile) {
       $myfile = $this->spool->spoolPath($pid,$globals->wordfile);
       $rcs->importWordFile($pid, $globals->htmlfile, $myfile);
     }
